@@ -35,5 +35,9 @@ __private_extern__ CFUserNotificationRef _showUPSWarning(void);
 
 __private_extern__ CFUserNotificationRef _showLowBatteryWarning(void);
 
+__private_extern__ IOReturn _setRootDomainProperty(
+                                    CFStringRef     key,
+                                    CFTypeRef       val);
+
 #endif
 
